==> forms-v5.2.1.tar.gz: forms/l10n/sl.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Vprašalniki",
    "{user} has shared the form {formTitle} with you" : "{user} vam omogoči dostop do obrazca {formTitle}",
    "{user} has shared the form {formTitle} with group {group}" : "{user} omogoči dostop do obrazca {formTitle} skupini {group}",
    "Anonymous user" : "Brezimni uporabnik",
    "A form has been <strong>shared</strong> with you" : "Vprašalnik vam je bil dodeljen v <strong>souporabo</strong>",
    "Someone <strong>answered</strong> a form" : "Nekdo je <strong>izpolnil</strong> vprašalnik",
    "Timestamp of data load" : "Časovni žig podatkovnega nabora",
    "No" : "Ne",
    "Yes" : "Da",
    "Question" : "Vprašanje",
    "Count" : "Števec",
    "Copy" : "Kopiraj",
    "Anonymous response" : "Anonimni odziv",
    "Shared by %s" : "Objavo omogoča %s",
    "Forms including questions and submissions" : "Vprašalniki z vprašanji in zbranimi podatki",
    "responses" : "odzivi",
    "User ID" : "ID Uporabnika",
    "User display name" : "Prikazno ime uporabnika",
    "Timestamp" : "Časovni žig",
    "📝 Simple surveys and questionnaires, self-hosted" : "Enostavni vprašalnik in ankete na domačem strežniku",
    "An error occurred while loading the forms list" : "Med nalaganjem seznama vprašalnikov je prišlo do napake",
    "Form not found" : "Vprašalnika ni mogoče najti",
    "Unable to create a new form" : "Novega vprašalnika ni mogoče ustvariti",
    "Unable to copy form" : "Vprašalnika ni mogoče kopirati",
    "New form" : "Nov vprašalnik",
    "Your forms" : "Moji vprašalniki",
    "Shared with you" : "V souporabi z vami",
    "Archived forms" : "Arhivirani vprašalniki",
    "Loading forms …" : "Poteka nalaganje vprašalnikov …",
    "No forms created yet" : "Ni še ustvarjenih vprašalnikov",
    "Create a form" : "Ustvarite vprašalnik",
    "Select a form or create a new one" : "Izberite vprašalnik oziroma ustvarite novega",
    "Please select a form" : "Izberite vprašalnik",
    "Create new form" : "Ustvari nov vprašalnik",
    "This form does not exist" : "Ta vprašalnik ne obstaja",
    "Form expired" : "Vprašalnik je pretekel",
    "This form has expired and is no longer taking answers" : "Vprašalnik je pretekel, zato odgovorov ni mogoče več pošiljati",
    "Error while saving configuration" : "Napaka shranjevanja nastavitev",
    "Error while reloading config" : "Napaka nalaganja nastavitev",
    "Form creation" : "Ustvarjanje vprašalnika",
    "Restrict form creation to selected groups" : "Omeji ustvarjanje vprašalnikov na izbrane skupine",
    "Select groups" : "Izbor skupin",
    "Form sharing" : "Objava vprašalnikov",
    "Allow sharing by link" : "Dovoli objavo po povezavi",
    "Allow sharing to all logged in accounts" : "Dovoli objavo za vse prijavljene račune",
    "Delete form" : "Izbriši vprašalnik",
    "Form closed" : "Vprašalnik je zaprt",
    "Expired {relativeDate}" : "Pretečeno {relativeDate}",
    "Expires {relativeDate}" : "Preteče {relativeDate}",
    "Error while deleting {title}" : "Napaka med brisanjem {title}",
    "Form actions" : "Dejanja vprašalnika",
    "Edit form" : "Uredi vprašalnik",
    "Share form" : "Objava vprašalnika",
    "Results" : "Zadetki",
    "Copy form" : "Kopiraj vprašalnik",
    "Unarchive form" : "Povrni vprašalnik",
    "Archive form" : "Arhiviraj vprašalnik",
    "Are you sure you want to delete {title}?" : "Ali ste prepričani, da želite izbrisati vprašalnik {title}?",
    "Cancel" : "Prekliči",
    "Add options" : "Dodaj možnost",
    "Add multiple options" : "Dodaj več možnosti",
    "Options" : "Možnosti",
    "Answer number {index}" : "Odgovor številka {index}",
    "Error while saving the answer" : "Prišlo je do napake med shranjevanjem odgovora",
    "Delete answer" : "Izbriši odgovor",
    "This question needs a title!" : "To vprašanje zahteva naslov",
    "Question number {index}" : "Vprašanje številka {index}",
    "Move question up" : "Pomakni vprašanje višje",
    "Move question down" : "Pomakni vprašanje nižje",
    "Title of question number {index}" : "Naslov vprašanja številka {index}",
    "Required" : "Zahtevano",
    "Technical name of the question" : "Tehnično ime vprašanja",
    "Technical name" : "Tehnično ime",
    "Copy question" : "Kopiraj vprašanje",
    "Delete question" : "Izbriši vprašanje",
    "Shuffle options" : "Premešaj možnosti",
    "Maximum file size" : "Največja velikost datoteke",
    "Delete" : "Izbriši",
    "Uploading …" : "Poteka pošiljanje ...",
    "A long answer for the question “{text}”" : "Dolg odgovor na vprašanje »{text}«",
    "Add \"other\"" : "Dodaj \"drugo\"",
    "Other:" : "Drugo:",
    "Other" : "Drugo",
    "A short answer for the question “{text}”" : "Kratek odgovor na vprašanje »{text}«",
    "No response" : "Ni odziva",
    "Delete this response" : "Izbriši ta odziv",
    "This can not be controlled, if the form has a public link or stores responses anonymously." : "Tega ni mogoče nadzorovati, če je vprašalnik objavljen z javno povezavo oziroma shranjuje odzive brezimno.",
    "Expired on {date}" : "Preteklo na {date}",
    "Expires on {date}" : "Preteče na {date}",
    "never" : "nikoli",
    "Store responses anonymously" : "Shrani odzive brezimno",
    "Allow multiple responses per person" : "Dovoli več odzivov vsakega uporabnika",
    "Set expiration date" : "Nastavi datum preteka",
    "Show expiration date on form" : "Pokaži datum preteka na vprašalniku",
    "Group" : "Skupina",
    "Team" : "Skupina",
    "Permissions" : "Dovoljenja",
    "View responses" : "Pregled odzivov",
    "Share link" : "Povezava za souporabo",
    "Add link" : "Dodaj povezavo",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Show QR code" : "Pokaži kodo QR",
    "Copy embedding code" : "Kopiraj vstavljivo kodo",
    "Remove link" : "Odstrani povezavo",
    "Internal link" : "Notranja povezava",
    "Only works for logged in accounts with access rights" : "Deluje le za prijavljene račune z ustreznimi dovoljenji",
    "Permit access to all logged in accounts" : "Dovoli dostop vsem prijavljenim računom",
    "Show to all accounts on sidebar" : "Prikaži vsem računom v stranski vrstici",
    "This form is now owned by" : "Ta obrazec je zdaj v lasti",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "Lastništvo od {name} boste prenesli na drug račun. Izberite račun, na katerega želite prenesti lastništvo.",
    "Confirmation text" : "Besedilo potrditve",
    "This can not be undone." : "Tega ni mogoče odpraviti.",
    "I understand, transfer this form" : "Razumem, prenesi ta obrazec",
    "View form" : "Pogled vprašalnika",
    "View" : "Pogled",
    "Edit" : "Uredi",
    "Show results" : "Pokaži odzive",
    "View mode" : "Način pogleda",
    "Share" : "Souporaba",
    "Responses are anonymous." : "Odzivi so anonimni.",
    "An asterisk (*) indicates mandatory questions." : "Zvezdica ( * ) določa obvezna vprašanja.",
    "Expired {relativeDate}." : "Pretečno {relativeDate}",
    "Expires {relativeDate}." : "Preteče {relativeDate}",
    "There was an error while adding the new question" : "Prišlo je do napake med dodajanjem novega vprašanja",
    "There was an error while removing the question" : "Prišlo je do napake med odstranjevanjem vprašanja",
    "Error while saving form" : "Prišlo je do napake med shranjevanjem vprašalnika",
    "Create form" : "Ustvari obrazec",
    "Loading {title} …" : "Poteka nalaganje {title} …",
    "Form is archived" : "Obrazec je arhiviran",
    "Form title" : "Naslov vprašalnika",
    "Description" : "Opis",
    "Add a question" : "Dodaj vprašanje",
    "Summary" : "Povzetek",
    "Responses" : "Odzivi",
    "Create spreadsheet" : "Ustvarite preglednico",
    "There was an error while loading the results" : "Prišlo je do napake med nalaganjem zadetkov",
    "Export successful to {file}" : "Izvoz v {file} je uspešno končan.",
    "There was an error, while exporting to Files" : "Prišlo je do napake med izvažanjem med Datoteke",
    "There was an error while removing this response" : "Prišlo je do napake med odstranjevanjem odziva",
    "There was an error while removing responses" : "Prišlo je do napake med odstranjevanjem odzivov",
    "{amount} responses" : "Število odzivov: {amount}",
    "Open spreadsheet" : "Odprite preglednico",
    "Save copy to Files" : "Kopijo shranite v Datoteke",
    "Download" : "Prejmi",
    "Delete all responses" : "Izbriši vse odzive",
    "Search" : "Poišči",
    "Loading responses …" : "Poteka nalaganje odzivov ...",
    "No results found" : "Ni najdenih zadetkov",
    "No responses yet" : "Ni še odzivov",
    "Results of submitted forms will show up here" : "Rezultati poslanih anket bodo prikazani na tem mestu.",
    "Are you sure you want to delete all responses of {title}?" : "Ali ste prepričani, da želite izbrisati vse odzive v anketi {title}?",
    "Form settings" : "Nastavitve vprašalnika",
    "Sharing" : "Souporaba",
    "Settings" : "Nastavitve",
    "Abort" : "Prekini",
    "Submit" : "Pošlji",
    "Clear" : "Počisti",
    "There was an error submitting the form" : "Prišlo je do napake med pošiljanjem vprašalnika",
    "Submit form" : "Objavi obrazec",
    "Submitting form …" : "Poteka objavljanje obrazca ...",
    "Thank you for completing the form!" : "Hvala za izpolnjevanje vprašalnika!",
    "You have unsaved changes! Do you still want to leave?" : "Zaznane so neshranjene spremembe! Ali vseeno želite zapustiti stran?",
    "Error while saving question" : "Prišlo je do napake med shranjevanjem vprašanja",
    "There was an issue deleting this option" : "Prišlo je do napake med brisanjem možnosti",
    "Form link copied" : "Povezava vprašalnika je kopirana",
    "Cannot copy, please copy the link manually" : "Povezave ni mogoče kopirati. Storite to ročno.",
    "No recommendations. Start typing." : "Ni priporočil; začnite vpisovati",
    "No elements found." : "Ni najdenih predmetov",
    "Checkboxes" : "Izbor več možnosti",
    "Checkbox question title" : "Vprašanje z izborom več možnosti",
    "Enter your answer" : "Vpišite odgovor",
    "This question needs a title and at least one answer!" : "To vprašanje zahteva vprašanje in vsaj en možen odgovor!",
    "Radio buttons" : "Izbirni gumb",
    "Radio buttons question title" : "Vprašanje za izbor ene možnosti",
    "Dropdown" : "Spustni seznam možnosti",
    "Dropdown question title" : "Vprašanje s spustno izbiro možnosti",
    "People can pick one option" : "Izbrati je mogoče eno izmed možnosti.",
    "Pick an option" : "Izberite eno možnost ...",
    "File" : "Datoteka",
    "Short answer" : "Kratek odgovor",
    "Short answer question title" : "Vprašanje, ki zahteva kratek odgovor",
    "People can enter a short answer" : "Vpisati je treba kratek odgovor.",
    "Long text" : "Dolg odgovor",
    "Long text question title" : "Vprašanje, ki zahteva dolg odgovor",
    "People can enter a long text" : "Vpisati je treba dolg odgovor.",
    "Date" : "Izbor datuma",
    "Date question title" : "Vprašanje za izbor datuma",
    "People can pick a date" : "Izbrati je treba datum iz koledarja",
    "Pick a date" : "Izberite datum ...",
    "Datetime" : "Izbor datuma in časa",
    "Datetime question title" : "Vprašanje za izbor datuma in časa",
    "People can pick a date and time" : "Izbrati je treba datum in čas iz koledarja",
    "Pick a date and time" : "Izberite datum in čas ...",
    "Time" : "Čas",
    "Time question title" : "Vprašanje za izbor časa",
    "People can pick a time" : "Izbrati je mogoče določen čas",
    "Pick a time" : "Izbor časa",
    "Color" : "Barva",
    "Image" : "Slika",
    "Document" : "Dokument",
    "Presentation" : "Predstavitev",
    "Spreadsheet" : "Preglednica",
    "Text" : "Besedilo",
    "Phone number" : "Telefonska številka",
    "Email address" : "Elektronski naslov",
    "Number" : "Številčne vrednosti"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> forms-v5.2.3.tar.gz: forms/l10n/sl.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Vprašalniki",
    "{user} has shared the form {formTitle} with you" : "{user} vam omogoči dostop do obrazca {formTitle}",
    "{user} has shared the form {formTitle} with group {group}" : "{user} omogoči dostop do obrazca {formTitle} skupini {group}",
    "Anonymous user" : "Brezimni uporabnik",
    "A form has been <strong>shared</strong> with you" : "Vprašalnik vam je bil dodeljen v <strong>souporabo</strong>",
    "Someone <strong>answered</strong> a form" : "Nekdo je <strong>izpolnil</strong> vprašalnik",
    "Timestamp of data load" : "Časovni žig podatkovnega nabora",
    "No" : "Ne",
    "Yes" : "Da",
    "Question" : "Vprašanje",
    "Count" : "Števec",
    "Copy" : "Kopiraj",
    "Anonymous response" : "Anonimni odziv",
    "Shared by %s" : "Objavo omogoča %s",
    "Forms including questions and submissions" : "Vprašalniki z vprašanji in zbranimi podatki",
    "responses" : "odzivi",
    "User ID" : "ID Uporabnika",
    "User display name" : "Prikazno ime uporabnika",
    "Timestamp" : "Časovni žig",
    "📝 Simple surveys and questionnaires, self-hosted" : "Enostavni vprašalnik in ankete na domačem strežniku",
    "An error occurred while loading the forms list" : "Med nalaganjem seznama vprašalnikov je prišlo do napake",
    "Form not found" : "Vprašalnika ni mogoče najti",
    "Unable to create a new form" : "Novega vprašalnika ni mogoče ustvariti",
    "Unable to copy form" : "Vprašalnika ni mogoče kopirati",
    "New form" : "Nov vprašalnik",
    "Your forms" : "Moji vprašalniki",
    "Shared with you" : "V souporabi z vami",
    "Archived forms" : "Arhivirani vprašalniki",
    "No forms created yet" : "Ni še ustvarjenih vprašalnikov",
    "Create a form" : "Ustvarite vprašalnik",
    "Select a form or create a new one" : "Izberite vprašalnik oziroma ustvarite novega",
    "Please select a form" : "Izberite vprašalnik",
    "Create new form" : "Ustvari nov vprašalnik",
    "This form does not exist" : "Ta vprašalnik ne obstaja",
    "Form expired" : "Vprašalnik je pretekel",
    "This form has expired and is no longer taking answers" : "Vprašalnik je pretekel, zato odgovorov ni mogoče več pošiljati",
    "Error while saving configuration" : "Napaka shranjevanja nastavitev",
    "Error while reloading config" : "Napaka nalaganja nastavitev",
    "Form creation" : "Ustvarjanje vprašalnika",
    "Restrict form creation to selected groups" : "Omeji ustvarjanje vprašalnikov na izbrane skupine",
    "Select groups" : "Izbor skupin",
    "Form sharing" : "Objava vprašalnikov",
    "Allow sharing by link" : "Dovoli objavo po povezavi",
    "Allow sharing to all logged in accounts" : "Dovoli objavo za vse prijavljene račune",
    "Delete form" : "Izbriši vprašalnik",
    "Form closed" : "Vprašalnik je zaprt",
    "Expired {relativeDate}" : "Pretečeno {relativeDate}",
    "Expires {relativeDate}" : "Preteče {relativeDate}",
    "Error while deleting {title}" : "Napaka med brisanjem {title}",
    "Form actions" : "Dejanja vprašalnika",
    "Edit form" : "Uredi vprašalnik",
    "Share form" : "Objava vprašalnika",
    "Results" : "Zadetki",
    "Copy form" : "Kopiraj vprašalnik",
    "Unarchive form" : "Povrni vprašalnik",
    "Archive form" : "Arhiviraj vprašalnik",
    "Are you sure you want to delete {title}?" : "Ali ste prepričani, da želite izbrisati vprašalnik {title}?",
    "Cancel" : "Prekliči",
    "Add options" : "Dodaj možnost",
    "Add multiple options" : "Dodaj več možnosti",
    "Options" : "Možnosti",
    "Answer number {index}" : "Odgovor številka {index}",
    "Error while saving the answer" : "Prišlo je do napake med shranjevanjem odgovora",
    "Delete answer" : "Izbriši odgovor",
    "This question needs a title!" : "To vprašanje zahteva naslov",
    "Question number {index}" : "Vprašanje številka {index}",
    "Move question up" : "Pomakni vprašanje višje",
    "Move question down" : "Pomakni vprašanje nižje",
    "Title of question number {index}" : "Naslov vprašanja številka {index}",
    "Required" : "Zahtevano",
    "Technical name of the question" : "Tehnično ime vprašanja",
    "Technical name" : "Tehnično ime",
    "Copy question" : "Kopiraj vprašanje",
    "Delete question" : "Izbriši vprašanje",
    "Shuffle options" : "Premešaj možnosti",
    "Maximum file size" : "Največja velikost datoteke",
    "Delete" : "Izbriši",
    "A long answer for the question “{text}”" : "Dolg odgovor na vprašanje »{text}«",
    "Add \"other\"" : "Dodaj \"drugo\"",
    "Other:" : "Drugo:",
    "Other" : "Drugo",
    "A short answer for the question “{text}”" : "Kratek odgovor na vprašanje »{text}«",
    "No response" : "Ni odziva",
    "Delete this response" : "Izbriši ta odziv",
    "This can not be controlled, if the form has a public link or stores responses anonymously." : "Tega ni mogoče nadzorovati, če je vprašalnik objavljen z javno povezavo oziroma shranjuje odzive brezimno.",
    "Expired on {date}" : "Preteklo na {date}",
    "Expires on {date}" : "Preteče na {date}",
    "never" : "nikoli",
    "Store responses anonymously" : "Shrani odzive brezimno",
    "Allow multiple responses per person" : "Dovoli več odzivov vsakega uporabnika",
    "Set expiration date" : "Nastavi datum preteka",
    "Show expiration date on form" : "Pokaži datum preteka na vprašalniku",
    "Group" : "Skupina",
    "Team" : "Skupina",
    "Permissions" : "Dovoljenja",
    "View responses" : "Pregled odzivov",
    "Share link" : "Povezava za souporabo",
    "Add link" : "Dodaj povezavo",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Show QR code" : "Pokaži kodo QR",
    "Copy embedding code" : "Kopiraj vstavljivo kodo",
    "Remove link" : "Odstrani povezavo",
    "Internal link" : "Notranja povezava",
    "Only works for logged in accounts with access rights" : "Deluje le za prijavljene račune z ustreznimi dovoljenji",
    "Permit access to all logged in accounts" : "Dovoli dostop vsem prijavljenim računom",
    "Show to all accounts on sidebar" : "Prikaži vsem računom v stranski vrstici",
    "This form is now owned by" : "Ta obrazec je zdaj v lasti",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "Lastništvo od {name} boste prenesli na drug račun. Izberite račun, na katerega želite prenesti lastništvo.",
    "Confirmation text" : "Besedilo potrditve",
    "This can not be undone." : "Tega ni mogoče odpraviti.",
    "I understand, transfer this form" : "Razumem, prenesi ta obrazec",
    "View form" : "Pogled vprašalnika",
    "View" : "Pogled",
    "Edit" : "Uredi",
    "Show results" : "Pokaži odzive",
    "View mode" : "Način pogleda",
    "Share" : "Souporaba",
    "Responses are anonymous." : "Odzivi so anonimni.",
    "An asterisk (*) indicates mandatory questions." : "Zvezdica ( * ) določa obvezna vprašanja.",
    "Expired {relativeDate}." : "Pretečno {relativeDate}",
    "Expires {relativeDate}." : "Preteče {relativeDate}",
    "There was an error while adding the new question" : "Prišlo je do napake med dodajanjem novega vprašanja",
    "There was an error while removing the question" : "Prišlo je do napake med odstranjevanjem vprašanja",
    "Error while saving form" : "Prišlo je do napake med shranjevanjem vprašalnika",
    "Create form" : "Ustvari obrazec",
    "Form is archived" : "Obrazec je arhiviran",
    "Form title" : "Naslov vprašalnika",
    "Description" : "Opis",
    "Add a question" : "Dodaj vprašanje",
    "Summary" : "Povzetek",
    "Responses" : "Odzivi",
    "Create spreadsheet" : "Ustvarite preglednico",
    "There was an error while loading the results" : "Prišlo je do napake med nalaganjem zadetkov",
    "Export successful to {file}" : "Izvoz v {file} je uspešno končan.",
    "There was an error, while exporting to Files" : "Prišlo je do napake med izvažanjem med Datoteke",
    "There was an error while removing this response" : "Prišlo je do napake med odstranjevanjem odziva",
    "There was an error while removing responses" : "Prišlo je do napake med odstranjevanjem odzivov",
    "{amount} responses" : "Število odzivov: {amount}",
    "Open spreadsheet" : "Odprite preglednico",
    "Save copy to Files" : "Kopijo shranite v Datoteke",
    "Download" : "Prejmi",
    "Delete all responses" : "Izbriši vse odzive",
    "Search" : "Poišči",
    "No results found" : "Ni najdenih zadetkov",
    "No responses yet" : "Ni še odzivov",
    "Results of submitted forms will show up here" : "Rezultati poslanih anket bodo prikazani na tem mestu.",
    "Are you sure you want to delete all responses of {title}?" : "Ali ste prepričani, da želite izbrisati vse odzive v anketi {title}?",
    "Form settings" : "Nastavitve vprašalnika",
    "Sharing" : "Souporaba",
    "Settings" : "Nastavitve",
    "Abort" : "Prekini",
    "Submit" : "Pošlji",
    "Clear" : "Počisti",
    "There was an error submitting the form" : "Prišlo je do napake med pošiljanjem vprašalnika",
    "Submit form" : "Objavi obrazec",
    "Thank you for completing the form!" : "Hvala za izpolnjevanje vprašalnika!",
    "You have unsaved changes! Do you still want to leave?" : "Zaznane so neshranjene spremembe! Ali vseeno želite zapustiti stran?",
    "Error while saving question" : "Prišlo je do napake med shranjevanjem vprašanja",
    "There was an issue deleting this option" : "Prišlo je do napake med brisanjem možnosti",
    "Form link copied" : "Povezava vprašalnika je kopirana",
    "Cannot copy, please copy the link manually" : "Povezave ni mogoče kopirati. Storite to ročno.",
    "No recommendations. Start typing." : "Ni priporočil; začnite vpisovati",
    "No elements found." : "Ni najdenih predmetov",
    "Checkboxes" : "Izbor več možnosti",
    "Checkbox question title" : "Vprašanje z izborom več možnosti",
    "Enter your answer" : "Vpišite odgovor",
    "This question needs a title and at least one answer!" : "To vprašanje zahteva vprašanje in vsaj en možen odgovor!",
    "Radio buttons" : "Izbirni gumb",
    "Radio buttons question title" : "Vprašanje za izbor ene možnosti",
    "Dropdown" : "Spustni seznam možnosti",
    "Dropdown question title" : "Vprašanje s spustno izbiro možnosti",
    "People can pick one option" : "Izbrati je mogoče eno izmed možnosti.",
    "Pick an option" : "Izberite eno možnost ...",
    "File" : "Datoteka",
    "Short answer" : "Kratek odgovor",
    "Short answer question title" : "Vprašanje, ki zahteva kratek odgovor",
    "People can enter a short answer" : "Vpisati je treba kratek odgovor.",
    "Long text" : "Dolg odgovor",
    "Long text question title" : "Vprašanje, ki zahteva dolg odgovor",
    "People can enter a long text" : "Vpisati je treba dolg odgovor.",
    "Date" : "Izbor datuma",
    "Date question title" : "Vprašanje za izbor datuma",
    "People can pick a date" : "Izbrati je treba datum iz koledarja",
    "Pick a date" : "Izberite datum ...",
    "Datetime" : "Izbor datuma in časa",
    "Datetime question title" : "Vprašanje za izbor datuma in časa",
    "People can pick a date and time" : "Izbrati je treba datum in čas iz koledarja",
    "Pick a date and time" : "Izberite datum in čas ...",
    "Time" : "Čas",
    "Time question title" : "Vprašanje za izbor časa",
    "People can pick a time" : "Izbrati je mogoče določen čas",
    "Pick a time" : "Izbor časa",
    "Color" : "Barva",
    "Image" : "Slika",
    "Document" : "Dokument",
    "Presentation" : "Predstavitev",
    "Spreadsheet" : "Preglednica",
    "Text" : "Besedilo",
    "Phone number" : "Telefonska številka",
    "Email address" : "Elektronski naslov",
    "Number" : "Številčne vrednosti",
    "Loading forms …" : "Poteka nalaganje vprašalnikov …",
    "Uploading …" : "Poteka pošiljanje ...",
    "Loading {title} …" : "Poteka nalaganje {title} …",
    "Loading responses …" : "Poteka nalaganje odzivov ...",
    "Submitting form …" : "Poteka objavljanje obrazca ..."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
